#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.analysis_interfaces.analysis_case import AnalysisCase
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class AnalysisCases(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     AnalysisCases
                | 
                | The collection of analysis case making an Analysis.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=AnalysisCase)
        self.analysis_cases = com_object

    def add(self) -> AnalysisCase:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Add() As AnalysisCase
                | 
                |     Creates a new case and adds it to the case collection. This case will be
                |     plugged under the analysis model.
                | 
                |     Returns:
                |         The created case 
                |     Example:
                |         The following example creates a case NewCase in the case collection of
                |         the ModelAnalysis Analysis model
                | 
                |         .
                | 
                |          Dim ModelAnalysis As AnalysisModel
                |          Dim NewCase As AnalysisCase
                |          Set NewCase = ModelAnalysis.AnalysisCases.Add()

        :rtype: AnalysisCase
        """
        return AnalysisCase(self.analysis_cases.Add())

    def add_existing_case(self, i_case: AnalysisCase) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddExistingCase(AnalysisCase iCase)
                | 
                |     Adds an existing analysis case to the analysis cases
                |     collection.
                | 
                |     Parameters:
                | 
                |         iCase
                |             The Existing Analysis Case. 
                |         Example:
                |             This example adds ThisAnalysisCase in the analysisCases analysis
                |             cases collection.
                | 
                |              Dim ThisAnalysisCase As AnalysisCase
                |              Dim analysisCases As AnalysisCases
                |              ...
                |              analysisCases.AddExistingCase(ThisAnalysisCase)

        :param AnalysisCase i_case:
        :rtype: None
        """
        return self.analysis_cases.AddExistingCase(i_case.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_existing_case'
        # # vba_code = """
        # # Public Function add_existing_case(analysis_cases)
        # #     Dim iCase (2)
        # #     analysis_cases.AddExistingCase iCase
        # #     add_existing_case = iCase
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def item(self, i_index: cat_variant) -> AnalysisCase:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As AnalysisCase
                | 
                |     Returns a case using its index or its name from the case
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the case to retrieve from the collection
                |             of cases. As a numeric, this index is the rank of the case in the collection.
                |             The index of the first case in the collection is 1, and the index of the last
                |             case is Count. As a string, it is the name you assigned to the case using the
                |             
                | 
                |         AnyObject.Name property. 
                |     Returns:
                |         The retrieved case. 
                |     Example:
                |         This example retrieves in ThisCase the fifth case in the collection and
                |         in ThatCase the case named "MyCase in the case collection of the AnalysisModel
                |         Analysis model.
                | 
                |          Set CaseColl = AnalysisModel.AnalysisCases
                |          Set ThisCase = CaseColl.Item(5)
                |          Set ThatCase = CaseColl.Item("MyCase")

        :param cat_variant i_index:
        :rtype: AnalysisCase
        """
        return AnalysisCase(self.analysis_cases.Item(i_index))

    def new_case(self, i_type: str) -> AnalysisCase:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func NewCase(CATBSTR iType) As AnalysisCase
                | 
                |     Creates a new case and adds it to the case collection. This case will be
                |     plugged under the analysis model.
                | 
                |     Returns:
                |         The created case 
                |     Example:
                |         The following example creates a case NewCase in the case collection of
                |         the ModelAnalysis Analysis model
                | 
                |         .
                | 
                |          Dim ModelAnalysis As AnalysisModel
                |          Dim NewCase As AnalysisCase
                |          Set NewCase = ModelAnalysis.AnalysisCases.NewCase("AnalysisPreproCase")()

        :param str i_type:
        :rtype: AnalysisCase
        """
        return AnalysisCase(self.analysis_cases.NewCase(i_type))

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Remove(CATVariant iIndex)
                | 
                |     Removes a case using its index or its name from the case
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the case to retrieve from the collection
                |             of cases. As a numeric, this index is the rank of the case in the collection.
                |             The index of the first case in the collection is 1, and the index of the last
                |             case is Count. As a string, it is the name you assigned to the case using the
                |             
                | 
                |         AnyObject.Name property. 
                |     Example:
                |         This example removes the fifth case in the collection.
                | 
                |          AnalysisModel.AnalysisCases.Remove (5)

        :param cat_variant i_index:
        :rtype: None
        """
        return self.analysis_cases.Remove(i_index)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove'
        # # vba_code = """
        # # Public Function remove(analysis_cases)
        # #     Dim iIndex (2)
        # #     analysis_cases.Remove iIndex
        # #     remove = iIndex
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'AnalysisCases(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.knowledge_interfaces.parameter import Parameter
from pycatia.structure_interfaces.str_anchor_points import StrAnchorPoints
from pycatia.system_interfaces.any_object import AnyObject


class StrSection(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     StrSection
                | 
                | Represents the section object.
                | The section object is created from a part document in which a sketch has to be
                | defined.
                | The sketch object may contain one or several contour but all of them have to be
                | closed.
                | Predefined anchor points objects are calculated from the geometrical contour as
                | the top bottom point, the center gravity point, etc.
                | User anchor points can be created in the sketch using the parametric geometry
                | or not. However the names of these points have to prefixed by the string "Str"
                | to be recognized as structure anchor points.
                | Some attributes are defined on the section object but cannot be
                | modified.
                | A group of attributes defines the section name, the family name, and the the
                | name of the catalog where the section comes from.
                | Another attribute called the profile type defines the type of the parametric
                | contour used to create the section. The contour can be a Tee, an angle, a
                | channel, a square tube, and so on. These predefined contours are useful to
                | create a new catalog with some standard contours.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.str_section = com_object

    @property
    def catalog_name(self) -> Parameter:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CatalogName() As Parameter (Read Only)
                | 
                |     Returns the parameter defining the catalog name.
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim name As Parameter
                |          Set name = Section_1.CatalogName

        :rtype: Parameter
        """

        return Parameter(self.str_section.CatalogName)

    @property
    def family_name(self) -> Parameter:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FamilyName() As Parameter (Read Only)
                | 
                |     Returns the parameter defining the family name.
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim name As Parameter
                |          Set name = Section_1.FamilyName

        :rtype: Parameter
        """

        return Parameter(self.str_section.FamilyName)

    @property
    def profile_type(self) -> Parameter:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ProfileType() As Parameter (Read Only)
                | 
                |     Returns the parameter defining the profile type of the
                |     section.
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim type As Parameter
                |          Set type = Section_1.ProfileType

        :rtype: Parameter
        """

        return Parameter(self.str_section.ProfileType)

    @property
    def section_name(self) -> Parameter:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SectionName() As Parameter (Read Only)
                | 
                |     Returns the parameter defining the section name.
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim name As Parameter
                |          Set name = Section_1.SectionName

        :rtype: Parameter
        """

        return Parameter(self.str_section.SectionName)

    @property
    def str_anchor_points(self) -> StrAnchorPoints:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property StrAnchorPoints() As StrAnchorPoints (Read Only)
                | 
                |     Returns the collection of anchor points.
                | 
                |      
                | 
                | 
                |       
                |      Example: 
                |      
                |       
                |          
                | 
                |           Dim anchorPts As StrAnchorPoints
                |          Set anchorPts = Section_1.StrAnchorPoints

        :rtype: StrAnchorPoints
        """

        return StrAnchorPoints(self.str_section.StrAnchorPoints)

    def get_property(self, i_property: int, o_value: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetProperty(CATStrSectionProperties iProperty,
                | double oValue)
                | 
                |     Get a property value.
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim type As Parameter
                |          Set type = Section_1.GetProperty(CatStrArea)

        :param int i_property: enum cat_str_section_properties
        :param float o_value:
        :rtype: None
        """
        return self.str_section.GetProperty(i_property, o_value)

    def __repr__(self):
        return f'StrSection(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.workbench import Workbench
from pycatia.system_interfaces.any_object import AnyObject


class SchWorkbench(Workbench):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     InfInterfaces.Workbench
                |                         SchWorkbench
                | 
                | Represents a workbench on a schematic document.
                | Role:A workbench is a set of commands that can be used to create, modify and
                | edit the objects making up the document.
                | 
                | See also:
                |     Document
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_workbench = com_object

    def find_interface(self, i_interface_name: str, i_object: AnyObject) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func FindInterface(CATBSTR iInterfaceName,
                | CATBaseDispatch iObject) As CATBaseDispatch
                | 
                |     This method returns an interface handle to an object.
                | 
                |     Parameters:
                | 
                |         iInterfaceName
                |             interface name to search for ("CATIAxxxx") 
                |         iObject
                |             The object to search for the required interface. 
                |         oInterfaceFound
                |             interface handle found 
                | 
                |     Example:
                | 
                |           The following example retrieves a CATIAInterfaceNameToFind handle to
                |           the
                |          CATIAxxxx_iObject in interfaceFound using the Schematics workbench
                |          object
                |          schWorkbench.
                |
                |          Dim interfaceFound As AnyObject
                |          Set interfaceFound = CATIASchWorkbench.FindInterface("InterfaceNameToFind",CATIAProduct_iObject)

        :param str i_interface_name:
        :param AnyObject i_object:
        :rtype: AnyObject
        """
        return self.sch_workbench.FindInterface(i_interface_name, i_object.com_object)

    def __repr__(self):
        return f'SchWorkbench(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.knowledge_interfaces.parameter import Parameter
from pycatia.manufacturing_interfaces.manufacturing_feature import ManufacturingFeature
from pycatia.product_structure_interfaces.product import Product
from pycatia.system_interfaces.any_object import AnyObject


class ManufacturingPattern(ManufacturingFeature):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                    ManufacturingInterfaces.ManufacturingFeature
                |                         ManufacturingPattern
                | 
                | The Manufacturing Pattern is a specialized feature used to machine the same
                | item several times at several positions.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.manufacturing_pattern = com_object

    @property
    def tool_axis_strategy(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ToolAxisStrategy() As CATBSTR
                | 
                |     Returns or sets the Tool Axis Strategy of a Manufacturing
                |     Pattern.
                |     Legal values: The parameter name can be
                | 
                |     Fixed
                |     Variable
                |     NormalToPS
                | 
                | Examples:
                |     The following example returns the Tool Axis Strategy ThisToolAxisStrategy
                |     of the manufacturing pattern CurrentMfgPattern
                | 
                |      Dim ThisToolAxisStrategy As CATBSTR
                |      ThisToolAxisStrategy = CurrentMfgPattern.ToolAxisStrategy
                |      
                | 
                |     The next example sets the Tool Axis Strategy of the manufacturing pattern
                |     CurrentMfgPattern
                | 
                |      CurrentMfgPattern.ToolAxisStrategy = "Fixed"

        :rtype: str
        """

        return self.manufacturing_pattern.ToolAxisStrategy

    @tool_axis_strategy.setter
    def tool_axis_strategy(self, value: str):
        """
        :param str value:
        """

        self.manufacturing_pattern.ToolAxisStrategy = value

    def activate_point(self, i_point_number: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ActivatePoint(short iPointNumber)
                | 
                |     Activates a point of a Manufacturing Pattern.
                | 
                |     Parameters:
                | 
                |         iPointNumber
                |             The number of the point to activate.
                | 
                |             Example:
                |                 The following example activates the point number 2 of the
                |                 manufacturing pattern mfgPattern:
                | 
                |                  call mfgPattern.ActivatePoint(2)

        :param int i_point_number:
        :rtype: None
        """
        return self.manufacturing_pattern.ActivatePoint(i_point_number)

    def add_part_surface(self, i_part_surface: AnyObject, i_product: Product, i_notify: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddPartSurface(AnyObject iPartSurface,
                | Product iProduct,
                | short iNotify)
                | 
                |     Adds a Part Surface to the Manufacturing Pattern.
                | 
                |     Parameters:
                | 
                |         iPartSurface
                |             The part surface to be added. 
                |         iProduct
                |             The product containing the part surface to add. 
                |         iNotify
                |             The flag to specify if a refresh of the visualization is needed.
                |             Usually, this parameter is set to 1. In the case of a loop, it should be set to
                |             1 only on the last call of the method.
                |             Legal values: The parameter can be
                | 
                |             0
                |                 no notification is sent 
                |             1
                |                 a notification is sent 
                | 
                |             Example:
                |                 The following example adds the part surface 'TopPlane' to the
                |                 manufacturing pattern mfgPattern:
                | 
                |                  call mfgPattern.AddPartSurface(TopPlane,Product1,1)

        :param AnyObject i_part_surface:
        :param Product i_product:
        :param int i_notify:
        :rtype: None
        """
        return self.manufacturing_pattern.AddPartSurface(i_part_surface.com_object, i_product.com_object, i_notify)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_part_surface'
        # # vba_code = """
        # # Public Function add_part_surface(manufacturing_pattern)
        # #     Dim iPartSurface (2)
        # #     manufacturing_pattern.AddPartSurface iPartSurface
        # #     add_part_surface = iPartSurface
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_position(self, i_position: AnyObject, i_product: Product, i_notify: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddPosition(AnyObject iPosition,
                | Product iProduct,
                | short iNotify)
                | 
                |     Adds a position to the Manufacturing Pattern.
                | 
                |     Parameters:
                | 
                |         iPosition
                |             The position to be added.
                |             Legal values: The position can be a
                | 
                |             Design Hole
                |                 the point is the origin point of the hole 
                |             Design Pattern
                |                 points are retrieved from the design pattern 
                |             Point
                |                 the point coordinates are retrieved from the added point
                |                 
                |             Circle
                |                 the point is the center of the circle 
                | 
                |         iProduct
                |             The product containing the position to add. 
                |         iNotify
                |             The flag to specify if a refresh of the visualization is needed.
                |             Usually, this parameter is set to 1. In the case of a loop, it should be set to
                |             1 only on the last call of the method.
                |             Legal values: The parameter can be
                | 
                |             0
                |                 no notification is sent 
                |             1
                |                 a notification is sent 
                | 
                |             Example:
                |                 The following example adds the position 'DesignPattern1' to the
                |                 manufacturing pattern mfgPattern:
                | 
                |                  call mfgPattern.AddPosition(DesignPattern1,Product1,1)

        :param AnyObject i_position:
        :param Product i_product:
        :param int i_notify:
        :rtype: None
        """
        return self.manufacturing_pattern.AddPosition(i_position.com_object, i_product.com_object, i_notify)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_position'
        # # vba_code = """
        # # Public Function add_position(manufacturing_pattern)
        # #     Dim iPosition (2)
        # #     manufacturing_pattern.AddPosition iPosition
        # #     add_position = iPosition
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def deactivate_point(self, i_point_number: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub DeactivatePoint(short iPointNumber)
                | 
                |     Deactivates a point of a Manufacturing Pattern.
                | 
                |     Parameters:
                | 
                |         iPointNumber
                |             The number of the point to deactivate.
                | 
                |             Example:
                |                 The following example deactivates the point number 2 of the
                |                 manufacturing pattern mfgPattern:
                | 
                |                  call mfgPattern.DeactivatePoint(2)

        :param int i_point_number:
        :rtype: None
        """
        return self.manufacturing_pattern.DeactivatePoint(i_point_number)

    def get_an_attribute(self, i_attribute: str) -> Parameter:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAnAttribute(CATBSTR iAttribut) As Parameter
                | 
                |     Retreive the attribute of Manufacturing Pattern from its
                |     name.
                | 
                |     Parameters:
                | 
                |         iAttribute
                |             The identifier of the attribute to be read.
                |             Legal values: The identifier can be
                | 
                |             JumpDistance
                |                 the jump distance of the pattern 
                |             TopMode
                |                 the Top Mode of the pattern 
                | 
                |             Example:
                |                 The following example retrieves the attribute 'JumpDistance' of
                |                 the manufacturing pattern mfgPattern:
                | 
                |                  call mfgPattern.GetAnAttribute(JumpDistance,JumpParm)

        :param str i_attribute:
        :rtype: Parameter
        """
        return Parameter(self.manufacturing_pattern.GetAnAttribute(i_attribute))

    def get_local_tool_axis(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetLocalToolAxis(short iPointNumber,
                | double oX,
                | double oY,
                | double oZ)
                | 
                |     Retrieve the local tool axis of a point of a Manufacturing
                |     Pattern.
                | 
                |     Parameters:
                | 
                |         iPointNumber
                |             The number of the point on which the tool axis is set.
                |             
                |         oX
                |             The first coordinate of the tool axis. 
                |         oY
                |             The second coordinate of the tool axis. 
                |         oZ
                |             The third coordinate of the tool axis.
                | 
                |             Example:
                |                 The following example retrieves the tool axis of the point
                |                 number 3 of manufacturing pattern mfgPattern:
                | 
                |                  call mfgPattern.GetLocalToolAxis(3,oX,oY,oZ)

        :rtype: tuple
        """
        return self.manufacturing_pattern.GetLocalToolAxis()

    def get_numbers(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetNumbers(CATSafeArrayVariant oNumbers)
                | 
                |     Retrieve the number of the points of a Manufacturing
                |     Pattern.
                | 
                |     Parameters:
                | 
                |         oNumbers
                |             The numbers of the points of the pattern.
                | 
                |             Example:
                |                 The following example retrieves the numbers of the points of
                |                 the manufacturing pattern mfgPattern:
                | 
                |                  call mfgPattern.GetNumbers(oNumbers)

        :param tuple o_numbers:
        :rtype: None
        """
        return self.manufacturing_pattern.GetNumbers()
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_numbers'
        # # vba_code = """
        # # Public Function get_numbers(manufacturing_pattern)
        # #     Dim oNumbers (2)
        # #     manufacturing_pattern.GetNumbers oNumbers
        # #     get_numbers = oNumbers
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def remove_part_surfaces(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemovePartSurfaces()
                | 
                |     Remove the Part Surfaces of the Manufacturing Pattern.
                | 
                |     Example:
                |         The following example removes the part surfaces of the manufacturing
                |         pattern mfgPattern:
                | 
                |          call mfgPattern.RemovePartSurfaces()

        :rtype: None
        """
        return self.manufacturing_pattern.RemovePartSurfaces()

    def reverse(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Reverse()
                | 
                |     Reverses the numbering of a Manufacturing Pattern.
                | 
                |     Example:
                |         The following example reverses the numbering of the manufacturing
                |         pattern mfgPattern:
                | 
                |          call mfgPattern.Reverse()

        :rtype: None
        """
        return self.manufacturing_pattern.Reverse()

    def set_item_to_copy(self, i_item: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetItemToCopy(AnyObject iItem)
                | 
                |     Sets the feature to be copied.
                | 
                |     Parameters:
                | 
                |         iItemToCopy
                |             The feature to be copied. It may be a Design Hole or a
                |             Manufacturing Hole.
                |             Legal values: The parameter name can be
                | 
                |             Diameter
                |                 The hole diameter 
                | 
                |         oParameter
                |             The value of the parameter
                | 
                |             Example:
                |                 The following example sets the item to copy 'Hole1' to the
                |                 manufacturing pattern mfgPattern:
                | 
                |                  call mfgPattern.SetItemToCopy(Hole1)

        :param AnyObject i_item:
        :rtype: None
        """
        return self.manufacturing_pattern.SetItemToCopy(i_item.com_object)

    def set_local_tool_axis(self, i_point_number: int, i_x: float, i_y: float, i_z: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetLocalToolAxis(short iPointNumber,
                | double iX,
                | double iY,
                | double iZ)
                | 
                |     Sets a local tool axis to a point of a Manufacturing
                |     Pattern.
                | 
                |     Parameters:
                | 
                |         iPointNumber
                |             The number of the point on which the tool axis is set .
                |             
                |         iX
                |             The first coordinate of the tool axis. 
                |         iY
                |             The second coordinate of the tool axis. 
                |         iZ
                |             The third coordinate of the tool axis.
                | 
                |             Example:
                |                 The following example sets the Z axis as tool axis of the point
                |                 number 3 of manufacturing pattern mfgPattern:
                | 
                |                  call mfgPattern.SetLocalToolAxis(3,0,0,1)

        :param int i_point_number:
        :param float i_x:
        :param float i_y:
        :param float i_z:
        :rtype: None
        """
        return self.manufacturing_pattern.SetLocalToolAxis(i_point_number, i_x, i_y, i_z)

    def start_point(self, i_point_number: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub StartPoint(short iPointNumber)
                | 
                |     Sets a point of a Manufacturing Pattern as the start
                |     point.
                | 
                |     Parameters:
                | 
                |         iPointNumber
                |             The number of the point to set as start point.
                | 
                |             Example:
                |                 The following example sets the point number 2 as the start
                |                 point of the manufacturing pattern mfgPattern:
                | 
                |                  call mfgPattern.StartPoint(2)

        :param int i_point_number:
        :rtype: None
        """
        return self.manufacturing_pattern.StartPoint(i_point_number)

    def __repr__(self):
        return f'ManufacturingPattern(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import TYPE_CHECKING

from pycatia.system_interfaces.any_object import AnyObject

if TYPE_CHECKING:
    from pycatia.cat_sch_platform_interfaces.sch_grr_route import SchGRRRoute


class SchRouteSymbol(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchRouteSymbol
                | 
                | Manage a symbol placed on a route.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_route_symbol = com_object

    def flip_over_line(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub FlipOverLine()
                | 
                |     Mirror the symbol over the route segment line on which the symbol is
                |     positioned.
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchRouteSymbol
                |           ...
                |          objThisIntf.FlipOverLine

        :rtype: None
        """
        return self.sch_route_symbol.FlipOverLine()

    def flip_over_orthogonal_line(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub FlipOverOrthogonalLine()
                | 
                |     Mirror the symbol over the line orthogonal to the route segment line on
                |     which the symbol is positioned and going through the symbol's position point on
                |     that segment line.
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchRouteSymbol
                |           ...
                |          objThisIntf.FlipOverOrthogonalLine

        :rtype: None
        """
        return self.sch_route_symbol.FlipOverOrthogonalLine()

    def get_grr_route(self) -> 'SchGRRRoute':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetGRRRoute() As SchGRRRoute
                | 
                |     Get the graphical representation of a schematic route that owns this
                |     symbol.
                | 
                |     Parameters:
                | 
                |         oGRRRoute
                |             The graphical representation that owns this symbol.
                |
                |     Example:
                |
                |          Dim objThisIntf As SchRouteSymbol
                |          Dim objArg1 As SchGRRRoute
                |           ...
                |          Set objArg1 = objThisIntf.GetGRRRoute

        :rtype: SchGRRRoute
        """

        from pycatia.cat_sch_platform_interfaces.sch_grr_route import SchGRRRoute
        return SchGRRRoute(self.sch_route_symbol.GetGRRRoute())

    def get_position(self, o_seg_num: int, o_seg_parm: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetPosition(long oSegNum,
                | double oSegParm)
                | 
                |     Get the symbol's position on the route that own it.
                | 
                |     Parameters:
                | 
                |         oSegNum
                |             The route segment number. 
                |         oSegParm
                |             The parameter along the segment. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchRouteSymbol
                |          Dim intVar1 As Integer
                |          Dim dbVar2 As Double
                |           ...
                |          objThisIntf.GetPositionintVar1,dbVar2

        :param int o_seg_num:
        :param float o_seg_parm:
        :rtype: None
        """
        return self.sch_route_symbol.GetPosition(o_seg_num, o_seg_parm)

    def scale(self, i_db_scale_factor: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Scale(double iDbScaleFactor)
                | 
                |     Scale the symbol.
                | 
                |     Parameters:
                | 
                |         iDbScaleFactor
                |             The scale factor to scale the symbol by. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchRouteSymbol
                |          Dim dbVar1 As Double
                |           ...
                |          objThisIntf.ScaledbVar1

        :param float i_db_scale_factor:
        :rtype: None
        """
        return self.sch_route_symbol.Scale(i_db_scale_factor)

    def set_position(self, i_seg_num: int, i_seg_parm: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetPosition(long iSegNum,
                | double iSegParm)
                | 
                |     Set the symbol's position on the route that own it.
                | 
                |     Parameters:
                | 
                |         iSegNum
                |             The route segment number (<= number of segments in the route).
                |             
                |         iSegParm
                |             The parameter along the segment (0.<=iSegParm<=1.).
                |
                |     Example:
                |
                |          Dim objThisIntf As SchRouteSymbol
                |          Dim intVar1 As Integer
                |          Dim dbVar2 As Double
                |           ...
                |          objThisIntf.SetPositionintVar1,dbVar2

        :param int i_seg_num:
        :param float i_seg_parm:
        :rtype: None
        """
        return self.sch_route_symbol.SetPosition(i_seg_num, i_seg_parm)

    def __repr__(self):
        return f'SchRouteSymbol(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dnb_human_modeling_interfaces.swk_manikin_part import SWKManikinPart


class SWKAnthroVariable(SWKManikinPart):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DNBHumanModelingInterfaces.SWKManikinPart
                |                         SWKAnthroVariable
                | 
                | This interface is used to access an anthropometric variable.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.swk_anthro_variable = com_object

    @property
    def full_name(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FullName() As CATBSTR (Read Only)
                | 
                |     Returns the full name of the variable.
                |     This property is different from the property
                |     Name of AnyObject,
                |     which gives the short name or acronym name
                |     of the variable.
                | 
                |     For instance, if the variable in question is
                |     the head length, then property Name
                |     yields "<HEADLGTH>", whereas
                |     property FullName yields the character
                |     string "Head length".

        :rtype: str
        """

        return self.swk_anthro_variable.FullName

    @property
    def manual(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Manual() As boolean
                | 
                |     Returns or sets the management of the variable.
                |     A anthropometric variable being manual means that
                |     the variable's value is managed by the user and its current value will
                |     remain until the user changes it again.
                | 
                |     If the variable is not manual, then it is automatic, which means that the
                |     variable is managed by the system and that its value may be overriden, every
                |     time the anthropometry is updated.

        :rtype: bool
        """

        return self.swk_anthro_variable.Manual

    @manual.setter
    def manual(self, value: bool):
        """
        :param bool value:
        """

        self.swk_anthro_variable.Manual = value

    @property
    def max_value(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MaxValue() As double (Read Only)
                | 
                |     Returns the highest value that the variable can take. This value
                |     corresponds to percentile 100.
                | 
                |     If this variable is a mass, the value returned is in
                |     kilograms; if not, the value returned is in centimeters.

        :rtype: float
        """

        return self.swk_anthro_variable.MaxValue

    @property
    def mean(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Mean() As double (Read Only)
                | 
                |     Returns the mean value os the variable. This value corresponds to
                |     percentile 50.
                | 
                |     If this variable is a mass, the value returned is in
                |     kilograms; if not, the value returned is in centimeters.

        :rtype: float
        """

        return self.swk_anthro_variable.Mean

    @property
    def min_value(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MinValue() As double (Read Only)
                | 
                |     Returns the lowest value that the variable can take. This value corresponds
                |     to percentile 0.
                | 
                |     If this variable is a mass, the value returned is in
                |     kilograms; if not, the value returned is in centimeters.

        :rtype: float
        """

        return self.swk_anthro_variable.MinValue

    @property
    def reference_number(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ReferenceNumber() As long (Read Only)
                | 
                |     Returns the reference number of the variable.
                |     This reference number is unique to the variable.

        :rtype: int
        """

        return self.swk_anthro_variable.ReferenceNumber

    @property
    def std_dev(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property StdDev() As double (Read Only)
                | 
                |     Returns the standard deviation of the variable.
                | 
                |     If this variable is a mass, the value returned is in
                |     kilograms; if not, the value returned is in centimeters.

        :rtype: float
        """

        return self.swk_anthro_variable.StdDev

    @property
    def value(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Value() As double
                | 
                |     Returns or sets the value of the variable.

        :rtype: float
        """

        return self.swk_anthro_variable.Value

    @value.setter
    def value(self, value: float):
        """
        :param float value:
        """

        self.swk_anthro_variable.Value = value

    @property
    def value_as_percentile(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ValueAsPercentile() As double
                | 
                |     Returns or sets the value of the variable.
                |     When using that property, the number returned or set
                |     must be a percentile, that is, must be between 0.0 and 100.0
                |     inclusive.
                | 
                |     If this variable is a mass, the value returned or set is in
                |     kilograms, if not, the value returned or set is in centimeters.

        :rtype: float
        """

        return self.swk_anthro_variable.ValueAsPercentile

    @value_as_percentile.setter
    def value_as_percentile(self, value: float):
        """
        :param float value:
        """

        self.swk_anthro_variable.ValueAsPercentile = value

    @property
    def value_as_string(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ValueAsString() As CATBSTR
                | 
                |     Returns or sets the value of the variable, as a string.

        :rtype: str
        """

        return self.swk_anthro_variable.ValueAsString

    @value_as_string.setter
    def value_as_string(self, value: str):
        """
        :param str value:
        """

        self.swk_anthro_variable.ValueAsString = value

    def get_correlation_with(self, pi_ref_number_of_other: int) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetCorrelationWith(long piRefNumberOfOther) As double
                | 
                |     Returns the correlation between this variable and another.
                | 
                |     Parameters:
                | 
                |         piRefNumberOfOther
                |             The reference number of the other variable (ex.: 3 for us3, 100 for
                |             us100, etc).

        :param int pi_ref_number_of_other:
        :rtype: float
        """
        return self.swk_anthro_variable.GetCorrelationWith(pi_ref_number_of_other)

    def __repr__(self):
        return f'SWKAnthroVariable(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_str_functional_interfaces.sfm_connection_parameters import SFMConnectionParameters
from pycatia.in_interfaces.reference import Reference
from pycatia.system_interfaces.any_object import AnyObject
from pycatia.types.general import cat_variant


class SFMSlot(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SfmSlot
                | 
                | Interface to Get and Set inputs to existing Slot.
                | Role: Allows managing (mainly retreiving parameters)Slots.
                | 
                | See also:
                |     SfmProfile, SfmSuperPlate, SfmSlots, SfmConnectionParameters
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sfm_slot = com_object

    def get_cntn_detail_name(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetCntnDetailName() As CATBSTR
                | 
                |     Gets the name of the UDF used for creating the slot.
                | 
                |     Parameters:
                | 
                |         oUDFName
                |             [in] Name of the UDF. 
                | 
                |     Returns:
                |         S_OK if everything ran ok
                | 
                |         Example:
                |             This example gives the name of the UDF used in creating the
                |             slot.
                | 
                |              Dim SlotsonPlate As SfmSlots
                |              Set SlotsonPlate = SfmSuperPlateObj.GetSlotsOnPlate
                |              Dim SlotObj As SfmSlot
                |              Set SlotObj = SlotsonPlate.Item(1)
                |              Dim UDFName As String
                |              UDFName = SlotObj.GetCntnDetailName

        :rtype: str
        """
        return self.sfm_slot.GetCntnDetailName()

    def get_cntn_detail_parameters(
            self,
            o_list_of_slot_parameters: SFMConnectionParameters,
            o_list_of_parameter_names: tuple
    ) -> cat_variant:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetCntnDetailParameters(SfmConnectionParameters
                | oListOfSlotParameters,
                | CATSafeArrayVariant oListOfParameterNames)
                | 
                |     Gets the Information on Existing Slot.
                | 
                |     Parameters:
                | 
                |         oListOfSlotParameters
                |             [out] List of SfmConnectionParameters. 
                |         oListOfParameterNames
                |             [out] List of Parameter Names set. 
                | 
                |     Returns:
                |         S_OK if everything ran ok
                | 
                |         Example:
                |             This retrieves the Parameter List and Parameter Names and checks
                |             values assigned to these parameters.
                | 
                |              Dim SlotsonPlate As SfmSlots
                |              Set SlotsonPlate = SfmSuperPlateObj.GetSlotsOnPlate
                |              Dim SlotObj As SfmSlot
                |              Set SlotObj = SlotsonPlate.Item(1)
                |              Dim oListSlotParams As SfmConnectionParameters
                |              Dim ListOfParamNames() As Variant
                |              SlotObj.GetCntnDetailParametersoListSlotParams,ListOfParamNames
                |              Dim UDFParam As Parameter
                |              ParamCount = oListSlotParams.Count
                |              Dim Value As String
                |              For i = 1 To ParamCount
                |               Set UDFParam = oListSlotParams.Item(i)  
                |               Value = UDFParam.ValueAsString
                |              Next

        :param SFMConnectionParameters o_list_of_slot_parameters:
        :param tuple o_list_of_parameter_names:
        :rtype: cat_variant
        """
        return self.sfm_slot.GetCntnDetailParameters(o_list_of_slot_parameters.com_object, o_list_of_parameter_names)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_cntn_detail_parameters'
        # # vba_code = """
        # # Public Function get_cntn_detail_parameters(sfm_slot)
        # #     Dim oListOfSlotParameters (2)
        # #     sfm_slot.GetCntnDetailParameters oListOfSlotParameters
        # #     get_cntn_detail_parameters = oListOfSlotParameters
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_connection_coordinate(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetConnectionCoordinate() As CATSafeArrayVariant
                | 
                |     Gets thelocation of existing slot.
                | 
                |     Parameters:
                | 
                |         oCoordinate
                |             [out] The Coordinates. 
                | 
                |     Returns:
                |         S_OK if everything ran ok
                | 
                |         Example:
                |             The example retrieves slot Coordinates defined on start
                |             end.
                | 
                |              Dim SlotsonPlate As SfmSlots
                |              Set SlotsonPlate = SfmSuperPlateObj.GetSlotsOnPlate
                |              Dim SlotObj As SfmSlot
                |              Set SlotObj = SlotsonPlate.Item(1)
                |              Dim Coord() As Variant
                |              Dim x,y,z as Double
                |              Coord() = SlotObj.GetConnectionCoordinate
                |              x = Coord(0)
                |              y = Coord(1)
                |              z = Coord(2)

        :rtype: tuple
        """
        return self.sfm_slot.GetConnectionCoordinate()

    def get_master_object(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetMasterObject() As Reference
                | 
                |     Gets the Penetrating Element used in the creation of the
                |     Slot.
                | 
                |     Parameters:
                | 
                |         oPenetratingObject
                |             [out] The retrieved element(Profile). 
                | 
                |     Returns:
                |         S_OK if everything ran ok
                | 
                |         Example:
                |             This example gets the Master Object.
                | 
                |              Dim SlotsonPlate As SfmSlots
                |              Set SlotsonPlate = SfmSuperPlateObj.GetSlotsOnPlate
                |              Dim SlotObj As SfmSlot
                |              Set SlotObj = SlotsonPlate.Item(1)
                |              Dim oPenetratingRef As Reference
                |              Set oPenetratingRef = SlotObj.GetMasterObject

        :rtype: Reference
        """
        return Reference(self.sfm_slot.GetMasterObject())

    def get_slave_object(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetSlaveObject() As Reference
                | 
                |     Gets the Penetrated Element used in the creation of the
                |     Slot.
                | 
                |     Parameters:
                | 
                |         oPenetratedObject
                |             [out] The retrieved element(Plate/Profile). 
                | 
                |     Returns:
                |         S_OK if everything ran ok
                | 
                |         Example:
                |             This example gets the Slave Object.
                | 
                |              Dim SlotsonPlate As SfmSlots
                |              Set SlotsonPlate = SfmSuperPlateObj.GetSlotsOnPlate
                |              Dim SlotObj As SfmSlot
                |              Set SlotObj = SlotsonPlate.Item(1)
                |              Dim oPenetratedRef As Reference
                |              Set oPenetratedRef = SlotObj.GetSlaveObject

        :rtype: Reference
        """
        return Reference(self.sfm_slot.GetSlaveObject())

    def set_slave_object(self, i_slave_object: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetSlaveObject(Reference iSlaveObject)
                | 
                |     Sets/Replaces the Penetrated Element used in the creation of the
                |     Slot.
                | 
                |     Parameters:
                | 
                |         iSlaveObject
                |             [in] The retrieved element(Plate/Profile). 
                | 
                |     Returns:
                |         S_OK if everything ran ok
                | 
                |         Example:
                |             This example sets the Slave Object.
                | 
                |              Dim SlotsonPlate As SfmSlots
                |              Set SlotsonPlate = SfmSuperPlateObj.GetSlotsOnPlate
                |              Dim SlotObj As SfmSlot
                |              Set SlotObj = SlotsonPlate.Item(1)
                |              Dim oPenetratedRef As Reference
                |              Set oPenetratedRef = PartObj.CreateReferenceFromObject(SfmNewPlateObj)
                |              SlotObj.SetSlaveObject(oPenetratedRef)

        :param Reference i_slave_object:
        :rtype: None
        """
        return self.sfm_slot.SetSlaveObject(i_slave_object.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_slave_object'
        # # vba_code = """
        # # Public Function set_slave_object(sfm_slot)
        # #     Dim iSlaveObject (2)
        # #     sfm_slot.SetSlaveObject iSlaveObject
        # #     set_slave_object = iSlaveObject
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def update_connections_set(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub UpdateConnectionsSet()
                | 
                |     Updates the Connection Set.
                | 
                |     Returns:
                |         S_OK if everything ran ok
                | 
                |         Example:
                |             The example Updates the Connection Set.
                | 
                |              Dim SlotsonPlate As SfmSlots
                |              Set SlotsonPlate = SfmSuperPlateObj.GetSlotsOnPlate
                |              Dim SlotObj As SfmSlot
                |              Set SlotObj = SlotsonPlate.Item(1)
                |              SlotObj.UpdateConnectionsSet

        :rtype: None
        """
        return self.sfm_slot.UpdateConnectionsSet()

    def __repr__(self):
        return f'SFMSlot(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.manufacturing_interfaces.manufacturing_output import ManufacturingOutput
from pycatia.system_interfaces.any_object import AnyObject
from pycatia.system_interfaces.cat_base_unknown import CATBaseUnknown


class ManufacturingGeneratorData(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ManufacturingGeneratorData
                | 
                | Represents the manufacturing output stream object.
                | This object contains the output stream generated for the output files (APT,
                | etc.).
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.manufacturing_generator_data = com_object

    def add_object_to_generate(self, i_object: CATBaseUnknown) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddObjectToGenerate(CATBaseUnknown iObject)
                | 
                |     Adds an object to the output stream.
                | 
                |         With buffer: V5R13 and next <=> AddObjectToGenerate
                |         Without buffer: V5R12 and previous <=>
                |         AddObjectToGenerate
                |         From buffer: Debug only
                | 
                |     Parameters:
                | 
                |         iObject
                |             The object to add

        :param CATBaseUnknown i_object:
        :rtype: None
        """
        return self.manufacturing_generator_data.AddObjectToGenerate(i_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_object_to_generate'
        # # vba_code = """
        # # Public Function add_object_to_generate(manufacturing_generator_data)
        # #     Dim iObject (2)
        # #     manufacturing_generator_data.AddObjectToGenerate iObject
        # #     add_object_to_generate = iObject
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_object_to_generate_from_buffer(self, i_object: CATBaseUnknown) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddObjectToGenerateFromBuffer(CATBaseUnknown iObject)
                | 
                |     Adds an object to the output stream from the buffer.
                | 
                |     Parameters:
                | 
                |         iObject
                |             The object to add

        :param CATBaseUnknown i_object:
        :rtype: None
        """
        return self.manufacturing_generator_data.AddObjectToGenerateFromBuffer(i_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_object_to_generate_from_buffer'
        # # vba_code = """
        # # Public Function add_object_to_generate_from_buffer(manufacturing_generator_data)
        # #     Dim iObject (2)
        # #     manufacturing_generator_data.AddObjectToGenerateFromBuffer iObject
        # #     add_object_to_generate_from_buffer = iObject
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_object_to_generate_with_buffer(self, i_object: CATBaseUnknown) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddObjectToGenerateWithBuffer(CATBaseUnknown iObject)
                | 
                |     Adds an object to the output stream within the buffer.
                | 
                |     Parameters:
                | 
                |         iObject
                |             The object to add

        :param CATBaseUnknown i_object:
        :rtype: None
        """
        return self.manufacturing_generator_data.AddObjectToGenerateWithBuffer(i_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_object_to_generate_with_buffer'
        # # vba_code = """
        # # Public Function add_object_to_generate_with_buffer(manufacturing_generator_data)
        # #     Dim iObject (2)
        # #     manufacturing_generator_data.AddObjectToGenerateWithBuffer iObject
        # #     add_object_to_generate_with_buffer = iObject
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_object_to_generate_with_out_buffer(self, i_object: CATBaseUnknown) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddObjectToGenerateWithOutBuffer(CATBaseUnknown
                | iObject)
                | 
                |     Adds an object to the output stream without the buffer.
                | 
                |     Parameters:
                | 
                |         iObject
                |             The object to add

        :param CATBaseUnknown i_object:
        :rtype: None
        """
        return self.manufacturing_generator_data.AddObjectToGenerateWithOutBuffer(i_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_object_to_generate_with_out_buffer'
        # # vba_code = """
        # # Public Function add_object_to_generate_with_out_buffer(manufacturing_generator_data)
        # #     Dim iObject (2)
        # #     manufacturing_generator_data.AddObjectToGenerateWithOutBuffer iObject
        # #     add_object_to_generate_with_out_buffer = iObject
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_object_to_modal_values(self, i_object: CATBaseUnknown) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddObjectToModalValues(CATBaseUnknown iObject)
                | 
                |     Adds an object to the modal values manager only.
                | 
                |     Parameters:
                | 
                |         iObject
                |             The object to add

        :param CATBaseUnknown i_object:
        :rtype: None
        """
        return self.manufacturing_generator_data.AddObjectToModalValues(i_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_object_to_modal_values'
        # # vba_code = """
        # # Public Function add_object_to_modal_values(manufacturing_generator_data)
        # #     Dim iObject (2)
        # #     manufacturing_generator_data.AddObjectToModalValues iObject
        # #     add_object_to_modal_values = iObject
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_ft06_stream(self, o_stream: ManufacturingOutput) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetFT06Stream(ManufacturingOutput oStream)
                | 
                |     Retrieves the FT06 stream.
                | 
                |     Parameters:
                | 
                |         oStream
                |             The retrieved stream

        :param ManufacturingOutput o_stream:
        :rtype: None
        """
        return self.manufacturing_generator_data.GetFT06Stream(o_stream.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_ft06_stream'
        # # vba_code = """
        # # Public Function get_ft06_stream(manufacturing_generator_data)
        # #     Dim oStream (2)
        # #     manufacturing_generator_data.GetFT06Stream oStream
        # #     get_ft06_stream = oStream
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_last_object_to_generate(self, o_object: CATBaseUnknown) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetLastObjectToGenerate(CATBaseUnknown oObject)
                | 
                |     Retrieves the last object to generate.
                | 
                |     Parameters:
                | 
                |         oObject
                |             The retrieved object

        :param CATBaseUnknown o_object:
        :rtype: None
        """
        return self.manufacturing_generator_data.GetLastObjectToGenerate(o_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_last_object_to_generate'
        # # vba_code = """
        # # Public Function get_last_object_to_generate(manufacturing_generator_data)
        # #     Dim oObject (2)
        # #     manufacturing_generator_data.GetLastObjectToGenerate oObject
        # #     get_last_object_to_generate = oObject
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_output_stream(self, o_stream: ManufacturingOutput) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetOutputStream(ManufacturingOutput oStream)
                | 
                |     Retrieves the output stream.
                | 
                |     Parameters:
                | 
                |         oStream
                |             The retrieved stream

        :param ManufacturingOutput o_stream:
        :rtype: None
        """
        return self.manufacturing_generator_data.GetOutputStream(o_stream.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_output_stream'
        # # vba_code = """
        # # Public Function get_output_stream(manufacturing_generator_data)
        # #     Dim oStream (2)
        # #     manufacturing_generator_data.GetOutputStream oStream
        # #     get_output_stream = oStream
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def reset_all_modal_values(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ResetAllModalValues()
                | 
                |     Resets all modal values.

        :rtype: None
        """
        return self.manufacturing_generator_data.ResetAllModalValues()

    def set_last_object_to_generate(self, i_object: CATBaseUnknown) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetLastObjectToGenerate(CATBaseUnknown iObject)
                | 
                |     Sets the last Activity to generate.
                | 
                |     Parameters:
                | 
                |         iObject
                |             The activity to generate

        :param CATBaseUnknown i_object:
        :rtype: None
        """
        return self.manufacturing_generator_data.SetLastObjectToGenerate(i_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_last_object_to_generate'
        # # vba_code = """
        # # Public Function set_last_object_to_generate(manufacturing_generator_data)
        # #     Dim iObject (2)
        # #     manufacturing_generator_data.SetLastObjectToGenerate iObject
        # #     set_last_object_to_generate = iObject
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ManufacturingGeneratorData(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape


class HybridShapeTrim(HybridShape):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         HybridShapeTrim
                | 
                | Represents the hybrid shape trim object.
                | Role: To access the data of the hybrid shape trim object. This data
                | includes:
                | 
                |     The first element (surface or curve) to be trimmed
                |     The second element (surface or curve) to be trimmed
                |     The orientation corresponding to the first element
                |     The orientation corresponding to the second element
                | 
                | Use the CATIAHybridShapeFactory to create a HybridShapeTrim
                | object.
                | 
                | See also:
                |     HybridShapeFactory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_trim = com_object

    @property
    def automatic_extrapolation_mode(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property AutomaticExtrapolationMode() As boolean
                | 
                |     Gets or sets the automatic extrapolation mode status. AutomaticExtrapolationMode
                |     TRUE : Automatic extrapolation mode is on.
                |     FALSE : Automatic extrapolation mode is off.
                |
                |     This example retrieves in AutoExtrapolMode the automatic extrapolation mode status for the
                |     Trim hybrid shape feature.
                | 
                |      Dim AutoExtrapolMode As boolean
                |      AutoExtrapolMode = Trim.AutomaticExtrapolationMode

        :rtype: bool
        """

        return self.hybrid_shape_trim.AutomaticExtrapolationMode

    @automatic_extrapolation_mode.setter
    def automatic_extrapolation_mode(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_trim.AutomaticExtrapolationMode = value

    @property
    def connex(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Connex() As boolean
                | 
                |     Gets or sets connected mode.
                |     Connex
                |     TRUE : the check of connexity is enable. Connex
                |     FALSE : the check of connexity is disable.
                |
                |     This example retrieves in Connex the connected mode for the Trim hybrid shape feature.
                | 
                |      Dim Connex As boolean
                |      Connex = Trim.Connex

        :rtype: bool
        """

        return self.hybrid_shape_trim.Connex

    @connex.setter
    def connex(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_trim.Connex = value

    @property
    def first_elem(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FirstElem() As Reference
                | 
                |     Deprecated:
                |         V5R17 CATIAHybridShapeTrim#GetElem Returns or sets the first element to
                |         be trimmed. 
                |     Example:
                | 
                |           This example retrieves in Surface1 the first element to be trimmed
                |           
                |          for the hybTrim hybrid shape feature.
                |          
                | 
                |          Dim Surface1 As Reference
                |          Set Surface1 = hybTrim.FirstElem

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_trim.FirstElem)

    @first_elem.setter
    def first_elem(self, reference_element: Reference):
        """
        :param Reference reference_element:
        """

        self.hybrid_shape_trim.FirstElem = reference_element.com_object

    @property
    def first_orientation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FirstOrientation() As long
                | 
                |     Deprecated:
                |         V5R17 CATIAHybridShapeTrim#GetPreviousOrientation Returns or sets the
                |         first orientation used to compute the trim.
                |         Role: The orientation specifies the kept parts of the first element to
                |         be trimmed.
                | 
                |             When trimming surfaces:
                |                 If orientation value is 1: kept parts are specified by the
                |                 "natural" normal to the second object
                |                 If orientation value is -1: kept parts are specified by the
                |                 inverse of the "natural" normal to the second
                |                 object
                |             When trimming curves:
                |                 If orientation value is 1: kept parts are from the beginning of
                |                 the curve to the first intersection, and, if there is one, from the second to
                |                 the third intersection and so on until the end of the
                |                 curve
                |                 If orientation value is -1: kept parts are from the first
                |                 intersection to the second (if there is one), and, if there is one, from the
                |                 third to the fourth and so on until the end of the
                |                 curve.
                | 
                |     Example:
                | 
                |           This example retrieves in firstOrient the orientation
                |           of
                |          the first element used by the hybTrim hybrid shape
                |          feature.
                | 
                |          Dim firstOrient As long
                |          Set firstOrient = hybTrim.FirstOrientation

        :rtype: int
        """

        return self.hybrid_shape_trim.FirstOrientation

    @first_orientation.setter
    def first_orientation(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_trim.FirstOrientation = value

    @property
    def intersection_computation(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property IntersectionComputation() As boolean
                | 
                |     Gets or sets Intersection computation mode.
                |    IntersectionComputation
                |    TRUE : Intersection is computed.
                |    FALSE : Intersection is not computed.
                |
                |     This example retrieves in Intersection the Intersection computation mode for the Trim hybrid
                |     shape feature.
                | 
                |      Dim Intersection As boolean
                |      Intersection = Trim.IntersectionComputation

        :rtype: bool
        """

        return self.hybrid_shape_trim.IntersectionComputation

    @intersection_computation.setter
    def intersection_computation(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_trim.IntersectionComputation = value

    @property
    def keep_all_pieces(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property KeepAllPieces() As boolean
                | 
                |     Gets or Sets keep all pieces mode. Used for the trim pieces of shells only KeepAllPieces=
                |     TRUE : all the pieces are kept during update, KeepAllPieces=
                |     FALSE : only chosen pieces are kept during update (default).
                |
                |     This example retrieves in KeepAllPieces the Keep All Pieces mode for the Trim hybrid shape
                |     feature.
                | 
                |      Dim bKeepAllPieces As boolean
                |      bKeepAllPieces = Trim.KeepAllPieces

        :rtype: bool
        """

        return self.hybrid_shape_trim.KeepAllPieces

    @keep_all_pieces.setter
    def keep_all_pieces(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_trim.KeepAllPieces = value

    @property
    def manifold(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Manifold() As boolean
                | 
                |     Gets or sets manifold mode.
                |     Manifold = TRUE : the check of manifold is enable.
                |     Manifold = FALSE : the check of manifold is disable.
                |
                |     This example retrieves in Manifold the manifold mode for the Trim hybrid shape feature.
                | 
                |      Dim Manifold As boolean
                |      Connex = Trim.Manifold

        :rtype: bool
        """

        return self.hybrid_shape_trim.Manifold

    @manifold.setter
    def manifold(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_trim.Manifold = value

    @property
    def mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Mode() As long
                | 
                |    Gets or sets Trim mode. Mode =
                |    1 : Standard. =
                |    2 : Pieces.
                |
                |    This example retrieves in Mode the mode for the Trim hybrid shape feature.
                | 
                |    Dim Mode As long
                |    Mode = Trim.Mode

        :rtype: int
        """

        return self.hybrid_shape_trim.Mode

    @mode.setter
    def mode(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_trim.Mode = value

    @property
    def second_elem(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SecondElem() As Reference
                | 
                |     Deprecated:
                |         V5R17 CATIAHybridShapeTrim#GetElem Returns or sets the second element
                |         to be trimmed. 
                |     Example:
                | 
                |           This example retrieves in Surface2 the second element to be trimmed
                |           
                |          for the hybTrim hybrid shape trim object.
                |          
                | 
                |          Dim Surface2 As Reference
                |          Set Surface2 = hybTrim.SecondElem

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_trim.SecondElem)

    @second_elem.setter
    def second_elem(self, reference_element: Reference):
        """
        :param Reference reference_element:
        """

        self.hybrid_shape_trim.SecondElem = reference_element.com_object

    @property
    def second_orientation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SecondOrientation() As long
                | 
                |     Deprecated:
                |         V5R17 CATIAHybridShapeTrim#GetPreviousOrientation Returns or sets the
                |         second orientation used to compute the trim.
                |         Role: The orientation specifies the kept parts of the second element to
                |         be trimmed.
                | 
                |             When trimming surfaces:
                |                 If orientation value is 1: kept parts are specified by the
                |                 "natural" normal to the first object
                |                 If orientation value is -1: kept parts are specified by the
                |                 inverse of the "natural" normal to the first
                |                 object
                |             When trimming curves:
                |                 If orientation value is 1: kept parts are from the beginning of
                |                 the curve to the first intersection, and, if there is one, from the second to
                |                 the third intersection and so on until the end of the
                |                 curve
                |                 If orientation value is -1: kept parts are from the first
                |                 intersection to the second (if there is one), and, if there is one, from the
                |                 third to the fourth and so on until the end of the
                |                 curve.
                | 
                |     Example:
                | 
                |           This example retrieves in secondOrient the orientation
                |           of
                |          the second element used by the hybTrim hybrid shape trim
                |          object.
                | 
                |          Dim secondOrient As long
                |          Set secondOrient = hybTrim.SecondOrientation

        :rtype: int
        """

        return self.hybrid_shape_trim.SecondOrientation

    @second_orientation.setter
    def second_orientation(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_trim.SecondOrientation = value

    @property
    def simplify(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Simplify() As boolean
                | 
                |     Returns or sets whether the simplification of the resulting topology is or
                |     should be activated.
                |     Legal values: True to activate the simplification, and False
                |     otherwise.
                | 
                |     Example:
                | 
                |            This example activates the simplification of the resulting topology
                |            of
                |          the hybTrim hybrid shape trim object.
                |          
                | 
                |           hybTrim.Simplify = True

        :rtype: bool
        """

        return self.hybrid_shape_trim.Simplify

    @simplify.setter
    def simplify(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_trim.Simplify = value

    @property
    def support(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Support() As Reference
                | 
                |     Returns or sets the support element.
                |     This support element may not exist.
                |     Sub-element(s) supported (see Boundary object): Face.
                | 
                |     Example:
                | 
                |           This example retrieves in supportElement the support
                |           element
                |          of the hybTrim hybrid shape trim object.
                |          
                | 
                |          Dim supportElement As Reference
                |          Set supportElement = hybTrim.Support

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_trim.Support)

    @support.setter
    def support(self, reference_support: Reference):
        """
        :param Reference reference_support:
        """

        self.hybrid_shape_trim.Support = reference_support.com_object

    def add_element_to_keep(self, i_element: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub AddElementToKeep(Reference iElement)
                | 
                |     Adds an element to specifications. This element will be
                |     kept.
                | 
                |     Parameters:
                | 
                |         iElement
                |             Element to keep.

        :param Reference i_element:
        :rtype: None
        """
        return self.hybrid_shape_trim.AddElementToKeep(i_element.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_element_to_keep'
        # # vba_code = """
        # # Public Function add_element_to_keep(hybrid_shape_trim)
        # #     Dim iElement (2)
        # #     hybrid_shape_trim.AddElementToKeep iElement
        # #     add_element_to_keep = iElement
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_element_to_remove(self, i_element: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub AddElementToRemove(Reference iElement)
                | 
                |     Adds an element to specifications. This element will be
                |     removed.
                | 
                |     Parameters:
                | 
                |         iElement
                |             Element to remove.

        :param Reference i_element:
        :rtype: None
        """
        return self.hybrid_shape_trim.AddElementToRemove(i_element.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_element_to_remove'
        # # vba_code = """
        # # Public Function add_element_to_remove(hybrid_shape_trim)
        # #     Dim iElement (2)
        # #     hybrid_shape_trim.AddElementToRemove iElement
        # #     add_element_to_remove = iElement
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_piece_cutter(self, i_rank: int, i_cutter_elem: int, i_orientation: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub AddPieceCutter(long iRank,
                | long iCutterElem,
                | long iOrientation)
                | 
                |     Add piece Cutting element and its orientation. Used for trim pieces of
                |     shells only
                | 
                |     Parameters:
                | 
                |         iRank
                |             Index of the trimmed element (piece) 
                |         iCutterElemIdx
                |             index is the index of input shell except in case of multiple intersection between shells
                |             where Index=IndexInputShell+NbInputShells*(1-iw)
                |             (with iw=1... : wire index in case of multiple intersection)
                |         iOrientation
                |             cutter element orientation

        :param int i_rank:
        :param int i_cutter_elem:
        :param int i_orientation:
        :rtype: None
        """
        return self.hybrid_shape_trim.AddPieceCutter(i_rank, i_cutter_elem, i_orientation)

    def get_elem(self, i_rank: int) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetElem(long iRank) As Reference
                | 
                |     Gets the trimmed feature at a given index.
                | 
                |     Parameters:
                | 
                |         iRank
                |             Index of one of the trimmed features 
                |         oElem
                |             trimmed feature

        :param int i_rank:
        :rtype: Reference
        """
        return Reference(self.hybrid_shape_trim.GetElem(i_rank))

    def get_kept_elem(self, i_rank: int) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetKeptElem(long iRank) As Reference
                | 
                |     Gets the kept feature at a given index.
                | 
                |     Parameters:
                | 
                |         oElem
                |             Kept feature 
                |         iRank
                |             Index of one of the kept features

        :param int i_rank:
        :rtype: Reference
        """
        return Reference(self.hybrid_shape_trim.GetKeptElem(i_rank))

    def get_nb_elem(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetNbElem() As long
                | 
                |     Gets the number of elements: couple(element, index of portion to keep on
                |     element).
                | 
                |     Parameters:
                | 
                |         oNbElem
                |             Number of elements

        :rtype: int
        """
        return self.hybrid_shape_trim.GetNbElem()

    def get_nb_elements_to_keep(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetNbElementsToKeep() As long
                | 
                |     Gets the number of elements to keep.
                | 
                |     Parameters:
                | 
                |         oNbElementsToKeep
                |             Number of elements to keep

        :rtype: int
        """
        return self.hybrid_shape_trim.GetNbElementsToKeep()

    def get_nb_elements_to_remove(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetNbElementsToRemove() As long
                | 
                |     Gets the number of elements to remove.
                | 
                |     Parameters:
                | 
                |         oNbElementsToRemove
                |             Number of elements to remove

        :rtype: int
        """
        return self.hybrid_shape_trim.GetNbElementsToRemove()

    def get_next_orientation(self, i_rank: int) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetNextOrientation(long iRank) As long
                | 
                |     Gets Orientation used to compute the feature, referring to the next trimmed
                |     element.
                | 
                |     Parameters:
                | 
                |         iRank
                |             index (of one of the trimmed features) - 1 iRank must be greater
                |             than 1 and lower than the number of elements - 1 
                |         oOrientation
                |             Orientation

        :param int i_rank:
        :rtype: int
        """
        return self.hybrid_shape_trim.GetNextOrientation(i_rank)

    def get_piece_cutter(self, i_rank: int, i_cutter_index: int, o_cutter_elem_idx: int, o_orientation: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetPieceCutter(long iRank,
                | long iCutterIndex,
                | long oCutterElemIdx,
                | long oOrientation)
                | 
                |     Gets piece Cutting element and its orientation. Used for trim pieces of
                |     shells only
                | 
                |     Parameters:
                | 
                |         iRank
                |             Index of the trimmed element (piece) 
                |         oCutterElemIdx
                |             index is the index of input shell except in case of multiple intersection between shells
                |             where Index=IndexInputShell+NbInputShells*(1-iw)
                |             (with iw=1... : wire index in case of multiple intersection)
                |         oCutterElem
                |             cutter element 
                |         oOrientation
                |             cutter element orientation

        :param int i_rank:
        :param int i_cutter_index:
        :param int o_cutter_elem_idx:
        :param int o_orientation:
        :rtype: None
        """
        return self.hybrid_shape_trim.GetPieceCutter(i_rank, i_cutter_index, o_cutter_elem_idx, o_orientation)

    def get_piece_discrimination_index(self, i_rank: int, o_index: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetPieceDiscriminationIndex(long iRank,
                | long oIndex)
                | 
                |     Gets the discrimination index. Used for the trim pieces of shells
                |     only
                | 
                |     Parameters:
                | 
                |         iRank
                |             Index of the trimmed element (piece) 
                |         oIndex
                |             Discrimination Index Used to discrimine pieces when cutters
                |             orientations are not enough

        :param int i_rank:
        :param int o_index:
        :rtype: None
        """
        return self.hybrid_shape_trim.GetPieceDiscriminationIndex(i_rank, o_index)

    def get_piece_nb_cutters(self, i_rank: int) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetPieceNbCutters(long iRank) As long
                | 
                |     Gets the number of cutters of a piece. Used for trim pieces of shells
                |     only
                | 
                |     Parameters:
                | 
                |         oNbCutters
                |             Number of cutters (except in case of multiple intersection between
                |             shells)

        :param int i_rank:
        :rtype: int
        """
        return self.hybrid_shape_trim.GetPieceNbCutters(i_rank)

    def get_portion_to_keep(self, i_rank: int) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetPortionToKeep(long iRank) As long
                | 
                |     Gets a portion to keep number, giving the index of the element. Used for
                |     trim pieces of wires
                | 
                |     Parameters:
                | 
                |         oPortionNumber
                |             Index of portion to keep on the element 
                |         iRank
                |             Index of the trimmed element

        :param int i_rank:
        :rtype: int
        """
        return self.hybrid_shape_trim.GetPortionToKeep(i_rank)

    def get_previous_orientation(self, i_rank: int) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetPreviousOrientation(long iRank) As long
                | 
                |     Gets Orientation used to compute the feature, referring to the previous
                |     trimmed element.
                | 
                |     Parameters:
                | 
                |         iRank
                |             index (of one of the trimmed features) - 1 iRank must be greater
                |             than 1 and lower than the number of elements - 1 
                |         oOrientation
                |             Orientation

        :param int i_rank:
        :rtype: int
        """
        return self.hybrid_shape_trim.GetPreviousOrientation(i_rank)

    def get_removed_elem(self, i_rank: int) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetRemovedElem(long iRank) As Reference
                | 
                |     Gets the removed feature at a given index.
                | 
                |     Parameters:
                | 
                |         oElem
                |             Removed feature 
                |         iRank
                |             Index of one of the removed features

        :param int i_rank:
        :rtype: Reference
        """
        return Reference(self.hybrid_shape_trim.GetRemovedElem(i_rank))

    def invert_first_orientation(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub InvertFirstOrientation()
                | 
                |     Deprecated:
                |         V5R17 CATIAHybridShapeTrim#SetPreviousOrientation Inverts the first
                |         orientation used to compute the trim. 
                |     Example:
                | 
                |           This example inverts the first orientation to
                |           compute
                |          the hybTrim hybrid shape trim object.
                | 
                |          hybTrim.InvertFirstOrientation

        :rtype: None
        """
        return self.hybrid_shape_trim.InvertFirstOrientation()

    def invert_second_orientation(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub InvertSecondOrientation()
                | 
                |     Deprecated:
                |         V5R17 CATIAHybridShapeTrim#SetPreviousOrientation Inverts the second
                |         orientation used to compute the trim. This example inverts the first
                |         orientation to compute the hybTrim hybrid shape trim
                |         object.
                | 
                |          hybTrim.InvertSecondOrientation

        :rtype: None
        """
        return self.hybrid_shape_trim.InvertSecondOrientation()

    def remove_element_to_keep(self, i_rank: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RemoveElementToKeep(long iRank)
                | 
                |     Removes an element from specifications.
                | 
                |     Parameters:
                | 
                |         iRank
                |             Index of the kept element.

        :param int i_rank:
        :rtype: None
        """
        return self.hybrid_shape_trim.RemoveElementToKeep(i_rank)

    def remove_element_to_remove(self, i_rank: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RemoveElementToRemove(long iRank)
                | 
                |     Removes an element from specifications.
                | 
                |     Parameters:
                | 
                |         iRank
                |             Index of the removed element.

        :param int i_rank:
        :rtype: None
        """
        return self.hybrid_shape_trim.RemoveElementToRemove(i_rank)

    def remove_piece_cutter(self, i_rank: int, i_cutter_index: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RemovePieceCutter(long iRank,
                | long iCutterIndex)
                | 
                |     Remove piece Cutting element and its orientation. Used for trim pieces of
                |     shells only
                | 
                |     Parameters:
                | 
                |         iRank
                |             Index of the trimmed element (piece) 
                |         iCutterIndex
                |             Index in cutters list

        :param int i_rank:
        :param int i_cutter_index:
        :rtype: None
        """
        return self.hybrid_shape_trim.RemovePieceCutter(i_rank, i_cutter_index)

    def set_elem(self, i_rank: int, i_elem: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetElem(long iRank,
                | Reference iElem)
                | 
                |     Modifies the trimmed feature at a given index. Use AddElem method to
                |     specify a new trimmed element
                | 
                |     Parameters:
                | 
                |         iRank
                |             Index of one of the trimmed features 
                |         iElem
                |             trimmed feature

        :param int i_rank:
        :param Reference i_elem:
        :rtype: None
        """
        return self.hybrid_shape_trim.SetElem(i_rank, i_elem.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_elem'
        # # vba_code = """
        # # Public Function set_elem(hybrid_shape_trim)
        # #     Dim iRank (2)
        # #     hybrid_shape_trim.SetElem iRank
        # #     set_elem = iRank
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_next_orientation(self, i_rank: int, i_orientation: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetNextOrientation(long iRank,
                | long iOrientation)
                | 
                |     Sets the orientation used to compute the feature, referring to the next
                |     trimmed element.
                | 
                |     Parameters:
                | 
                |         iRank
                |             index (of one of the trimmed features) - 1 iRank must be greater
                |             than 1 and lower than the number of elements - 1 
                |         iOrientation
                |             Orientation

        :param int i_rank:
        :param int i_orientation:
        :rtype: None
        """
        return self.hybrid_shape_trim.SetNextOrientation(i_rank, i_orientation)

    def set_piece_discrimination_index(self, i_rank: int, i_index: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetPieceDiscriminationIndex(long iRank,
                | long iIndex)
                | 
                |     Sets the discrimination index. Used for the trim pieces of shells
                |     only
                | 
                |     Parameters:
                | 
                |         iRank
                |             Index of the trimmed element (piece) 
                |         iIndex
                |             Discrimination Index Used to discrimine pieces when cutters
                |             orientations are not enough

        :param int i_rank:
        :param int i_index:
        :rtype: None
        """
        return self.hybrid_shape_trim.SetPieceDiscriminationIndex(i_rank, i_index)

    def set_portion_to_keep(self, i_rank: int, i_portion_number: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetPortionToKeep(long iRank,
                | long iPortionNumber)
                | 
                |     Sets a portion to keep number in Pieces mode. Used for trim pieces of
                |     wires
                | 
                |     Parameters:
                | 
                |         iRank
                |             Index of the trimmed element 
                |         iPortionNumber
                |             Index of portion to keep on the element

        :param int i_rank:
        :param int i_portion_number:
        :rtype: None
        """
        return self.hybrid_shape_trim.SetPortionToKeep(i_rank, i_portion_number)

    def set_previous_orientation(self, i_rank: int, i_orientation: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetPreviousOrientation(long iRank,
                | long iOrientation)
                | 
                |     Sets the orientation used to compute the feature, referring to the previous
                |     trimmed element.
                | 
                |     Parameters:
                | 
                |         iRank
                |             index (of one of the trimmed features) - 1 iRank must be greater
                |             than 1 and lower than the number of elements - 1 
                |         iOrientation
                |             Orientation

        :param int i_rank:
        :param int i_orientation:
        :rtype: None
        """
        return self.hybrid_shape_trim.SetPreviousOrientation(i_rank, i_orientation)

    def __repr__(self):
        return f'HybridShapeTrim(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_str_functional_interfaces.sfm_standard_contour_parameters import SFMStandardContourParameters
from pycatia.system_interfaces.any_object import AnyObject
from pycatia.types.general import cat_variant


class SFMOpeningContoursMgr(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SfmOpeningContoursMgr
                | 
                | Gets CATIASfmOpeningContoursMgr.
                | Use this manager to GetAvailableStdOpeningContours &
                | GetStdOpeningContourParams.
                | 
                | Example
                | :
                |     Retrives the Manager from factory
                | 
                |       'Get the Factory
                |       Set Factory =  part1.GetCustomerFactory("SfmFunctionFactory")
                |       'Retrieve the Contour Manager
                |       Dim ObjSfmContourMgr As SfmOpeningContoursMgr
                |       Set ObjSfmContourMgr = Factory.GetOpeningMgr(Part1, "SfmOpeningContoursMgr")
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sfm_opening_contours_mgr = com_object

    def get_available_std_opening_contours(self, o_list_contour_names: tuple) -> cat_variant:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetAvailableStdOpeningContours(CATSafeArrayVariant
                | oListContourNames)
                | 
                |     Get The list of Available Contours.
                | 
                |     Parameters:
                | 
                |         oListContourNames
                |             [out] Available Contour names 
                | 
                |     Returns:
                |         S_OK if everything ran ok
                | 
                |         Example
                |         :
                |             The Example demonstrates how to see available contours. Choose the
                |             required contour from the list.
                | 
                |               'Get the Factory
                |               Set Factory =  part1.GetCustomerFactory("SfmFunctionFactory")
                |               'Get the Contour Manager
                |               Dim ObjSfmContourMgr As SfmOpeningContoursMgr
                |               Set ObjSfmContourMgr = Factory.GetOpeningMgr(Part1, "SfmOpeningContoursMgr")
                |               'Get The List of Available Contours
                |               Dim oListContourNames() As Variant
                |               ObjSfmContourMgr.GetAvailableStdOpeningContours
                |               oListContourNames
                |               'Display The List of Available Contours
                |               Dim NbOfContour As Long
                |               NbOfContour = UBound(oListContourNames)
                |               Display List of contours
                |               For i = 0 To NbOfContour
                |               MsgBox oListContourNames(i)
                |               Next

        :param tuple o_list_contour_names:
        :rtype: cat_variant
        """
        return self.sfm_opening_contours_mgr.GetAvailableStdOpeningContours(o_list_contour_names)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_available_std_opening_contours'
        # # vba_code = """
        # # Public Function get_available_std_opening_contours(sfm_opening_contours_mgr)
        # #     Dim oListContourNames (2)
        # #     sfm_opening_contours_mgr.GetAvailableStdOpeningContours oListContourNames
        # #     get_available_std_opening_contours = oListContourNames
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_std_opening_contour_params(self, i_contour_name: str) -> SFMStandardContourParameters:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetStdOpeningContourParams(CATBSTR iContourName) As
                | SfmStandardContourParameters
                | 
                |     Get The list of Parameters for a selected Contour Name.The list varies
                |     depending on the type of contour.
                | 
                |     Parameters:
                | 
                |         iContourName
                |             [in] Contour names for which parameters need to be set.
                |             
                |         oListCkeParms
                |             [out] List of Parameters. 
                | 
                |     Returns:
                |         S_OK if everything ran ok
                | 
                |         Example:
                |             The Example demonstartes what parameters are required to be set for
                |             a chosen contour.Here "Sfm_Rect" is the chosen
                |             contour.
                | 
                |               'Retrieve the Factory
                |               Set Factory =  part1.GetCustomerFactory("SfmFunctionFactory")
                |               'Retrieve the Contour Manager
                |               Dim ObjSfmContourMgr As SfmOpeningContoursMgr
                |               Set ObjSfmContourMgr = Factory.GetOpeningMgr(Part1, "SfmOpeningContoursMgr")
                |               ' Enter Contour Name for which Parameter values need to be
                |               set
                |               Dim oListCkeParms As
                |               SfmStandardContourParameters
                |               Set oListCkeParms = ObjSfmContourMgr.GetStdOpeningContourParams("Sfm_Rect")
                |              'Display List of Parameters for Selected Contour
                |               Dim NbOfParam As Long
                |               NbOfParam = oListCkeParms.Count
                |               Dim ContourParam As Parameter
                |               Dim ContourParamName As String
                |               For i = 1 To NbOfParam
                |               Set ContourParam = oListCkeParms.Item(i)
                |               ContourParamName = oListCkeParms.Item(i).Name
                |               MsgBox ContourParamName
                |              'Set Contour Parameter Values
                |              If ContourParamName = "Sfm_Width" Then
                |                ContourParam.ValuateFromString ("1000mm")
                |                End If
                |              If ContourParamName = "Sfm_Height" Then
                |               ContourParam.ValuateFromString ("5000mm")
                |                End If
                |              If ContourParamName = "Sfm_CornerRadius" Then
                |               ContourParam.ValuateFromString ("10mm")
                |                End If
                |                Next

        :param str i_contour_name:
        :rtype: SFMStandardContourParameters
        """
        return SFMStandardContourParameters(self.sfm_opening_contours_mgr.GetStdOpeningContourParams(i_contour_name))

    def __repr__(self):
        return f'SFMOpeningContoursMgr(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class V4V5SpaceSettingAtt(SettingController):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         V4V5SpaceSettingAtt
                | 
                | Represents the object to handle the setting parameters of the "V4V5 Space" tab
                | page.
                | Role: This interface is implemented by a component named
                | CATV4IV4V5SpaceSettingCtrl which represents the controller of the Setting.
                | parameters displayed in the V4V5 Space Data property page. To access this
                | property page:
                | 
                |     Click the Options command in the Tools menu
                |     Click + left of General to unfold the workbench list
                |     Click Compatibility
                | 
                | 
                | The different options for V4/V5 SPACE tab are the following :
                | This interface defines:
                | 
                |     A method to get each parameter
                |     A method to set the value of each parameter
                |     A method to lock/unlock each parameter
                |     A method to retrieve the informations concerning each
                |     parameter
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.v4_v5_space_setting_att = com_object

    @property
    def details_mode_explode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property DetailsModeExplode() As long
                | 
                |     Returns or sets the activation state of mode for details migration (Explode
                |     Mode)
                |     Role: Returns or sets the state of mode for details migration.

        :rtype: int
        """

        return self.v4_v5_space_setting_att.DetailsModeExplode

    @details_mode_explode.setter
    def details_mode_explode(self, value: int):
        """
        :param int value:
        """

        self.v4_v5_space_setting_att.DetailsModeExplode = value

    @property
    def details_mode_usual(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property DetailsModeUsual() As long
                | 
                |     Returns or sets the activation state of mode for details migration (Usual
                |     Mode)
                |     Role: Returns or sets the state of mode for details migration.

        :rtype: int
        """

        return self.v4_v5_space_setting_att.DetailsModeUsual

    @details_mode_usual.setter
    def details_mode_usual(self, value: int):
        """
        :param int value:
        """

        self.v4_v5_space_setting_att.DetailsModeUsual = value

    @property
    def details_mode_wireframe(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property DetailsModeWireframe() As long
                | 
                |     Returns or sets the activation state of mode for details migration
                |     (WireFrame Mode)
                |     Role: Returns or sets the state of mode for details migration.

        :rtype: int
        """

        return self.v4_v5_space_setting_att.DetailsModeWireframe

    @details_mode_wireframe.setter
    def details_mode_wireframe(self, value: int):
        """
        :param int value:
        """

        self.v4_v5_space_setting_att.DetailsModeWireframe = value

    @property
    def external_max_deformation(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ExternalMaxDeformation() As double
                | 
                |     Returns or sets the activation state of mode with external deformation (Gap
                |     Healing).
                |     Role: Returns or sets the activation state of mode with external
                |     deformation (Gap Healing). during a Copy/Paste As Spec.

        :rtype: float
        """

        return self.v4_v5_space_setting_att.ExternalMaxDeformation

    @external_max_deformation.setter
    def external_max_deformation(self, value: float):
        """
        :param float value:
        """

        self.v4_v5_space_setting_att.ExternalMaxDeformation = value

    @property
    def external_type_deformation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ExternalTypeDeformation() As long
                | 
                |     Returns or sets the activation state of type for external deformation (Gap
                |     Healing).
                |     Role: Returns or sets the activation state of type for external deformation
                |     (Model relative or User defined value) during a Copy/Paste As Spec.

        :rtype: int
        """

        return self.v4_v5_space_setting_att.ExternalTypeDeformation

    @external_type_deformation.setter
    def external_type_deformation(self, value: int):
        """
        :param int value:
        """

        self.v4_v5_space_setting_att.ExternalTypeDeformation = value

    @property
    def internal_max_deformation(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property InternalMaxDeformation() As double
                | 
                |     Returns or sets the activation state of mode with internal deformation
                |     (Curve Improvement).
                |     Role: Returns or sets the activation state of mode with internal
                |     deformation during a Copy/Paste As Spec.

        :rtype: float
        """

        return self.v4_v5_space_setting_att.InternalMaxDeformation

    @internal_max_deformation.setter
    def internal_max_deformation(self, value: float):
        """
        :param float value:
        """

        self.v4_v5_space_setting_att.InternalMaxDeformation = value

    @property
    def internal_type_deformation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property InternalTypeDeformation() As long
                | 
                |     Returns or sets the activation state of type for internal deformation
                |     (Curve Improvement).
                |     Role: Returns or sets the activation state of type for internal deformation
                |     (Model relative or User defined value) during a Copy/Paste As Spec.

        :rtype: int
        """

        return self.v4_v5_space_setting_att.InternalTypeDeformation

    @internal_type_deformation.setter
    def internal_type_deformation(self, value: int):
        """
        :param int value:
        """

        self.v4_v5_space_setting_att.InternalTypeDeformation = value

    @property
    def keep_segmentation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property KeepSegmentation() As long
                | 
                |     Returns or sets the activation state of mode with segmentation (Keep V4
                |     Segmentation ).
                |     Role: Returns or sets the activation state of mode with segmentation during
                |     a Copy/Paste As Spec.

        :rtype: int
        """

        return self.v4_v5_space_setting_att.KeepSegmentation

    @keep_segmentation.setter
    def keep_segmentation(self, value: int):
        """
        :param int value:
        """

        self.v4_v5_space_setting_att.KeepSegmentation = value

    @property
    def solid_mu(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SolidMU() As CATBSTR
                | 
                |     Returns or sets the activation state of mode for isolated Solids Mock-Up
                |     migration
                |     Role: Returns or sets the state of mode for isolated Solids Mock-Up
                |     migration.

        :rtype: str
        """

        return self.v4_v5_space_setting_att.SolidMU

    @solid_mu.setter
    def solid_mu(self, value: str):
        """
        :param str value:
        """

        self.v4_v5_space_setting_att.SolidMU = value

    @property
    def text_migration(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TextMigration() As long
                | 
                |     Returns or sets the activation state of mode for 3D Text
                |     migration
                |     Role: Returns or sets the state of mode for 3D Text migration.

        :rtype: int
        """

        return self.v4_v5_space_setting_att.TextMigration

    @text_migration.setter
    def text_migration(self, value: int):
        """
        :param int value:
        """

        self.v4_v5_space_setting_att.TextMigration = value

    def get_details_mode_explode_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetDetailsModeExplodeInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the Details Migration Mode setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.v4_v5_space_setting_att.GetDetailsModeExplodeInfo(admin_level, o_locked)

    def get_details_mode_usual_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetDetailsModeUsualInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the Details Migration Mode setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.v4_v5_space_setting_att.GetDetailsModeUsualInfo(admin_level, o_locked)

    def get_details_mode_wireframe_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetDetailsModeWireframeInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the Details Migration Mode setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.v4_v5_space_setting_att.GetDetailsModeWireframeInfo(admin_level, o_locked)

    def get_external_max_deformation_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetExternalMaxDeformationInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the ExternalMaxDeformation setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.v4_v5_space_setting_att.GetExternalMaxDeformationInfo(admin_level, o_locked)

    def get_external_type_deformation_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetExternalTypeDeformationInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves environment informations for activation mode with external
                |     deformation (Gap Healing).
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.v4_v5_space_setting_att.GetExternalTypeDeformationInfo(admin_level, o_locked)

    def get_internal_max_deformation_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetInternalMaxDeformationInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the InternalMaxDeformation setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.v4_v5_space_setting_att.GetInternalMaxDeformationInfo(admin_level, o_locked)

    def get_internal_type_deformation_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetInternalTypeDeformationInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves environment informations for activation mode with internal
                |     deformation (Curve Improvement).
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.v4_v5_space_setting_att.GetInternalTypeDeformationInfo(admin_level, o_locked)

    def get_keep_segmentation_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetKeepSegmentationInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the KeepSegmentation setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.v4_v5_space_setting_att.GetKeepSegmentationInfo(admin_level, o_locked)

    def get_solid_mu_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetSolidMUInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the Solid Mock-Up Migration Mode setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.v4_v5_space_setting_att.GetSolidMUInfo(admin_level, o_locked)

    def get_text_migration_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetTextMigrationInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the 3D Text Migration setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.v4_v5_space_setting_att.GetTextMigrationInfo(admin_level, o_locked)

    def set_details_mode_explode_lock(self, i_lock: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetDetailsModeExplodeLock(boolean iLock)
                | 
                |     Locks or unlocks the Details Migration Mode setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_lock:
        :rtype: None
        """
        return self.v4_v5_space_setting_att.SetDetailsModeExplodeLock(i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_details_mode_explode_lock'
        # # vba_code = """
        # # Public Function set_details_mode_explode_lock(v4_v5_space_setting_att)
        # #     Dim iLock (2)
        # #     v4_v5_space_setting_att.SetDetailsModeExplodeLock iLock
        # #     set_details_mode_explode_lock = iLock
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_details_mode_usual_lock(self, i_lock: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetDetailsModeUsualLock(boolean iLock)
                | 
                |     Locks or unlocks the Details Migration Mode setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_lock:
        :rtype: None
        """
        return self.v4_v5_space_setting_att.SetDetailsModeUsualLock(i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_details_mode_usual_lock'
        # # vba_code = """
        # # Public Function set_details_mode_usual_lock(v4_v5_space_setting_att)
        # #     Dim iLock (2)
        # #     v4_v5_space_setting_att.SetDetailsModeUsualLock iLock
        # #     set_details_mode_usual_lock = iLock
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_details_mode_wireframe_lock(self, i_lock: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetDetailsModeWireframeLock(boolean iLock)
                | 
                |     Locks or unlocks the Details Migration Mode setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_lock:
        :rtype: None
        """
        return self.v4_v5_space_setting_att.SetDetailsModeWireframeLock(i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_details_mode_wireframe_lock'
        # # vba_code = """
        # # Public Function set_details_mode_wireframe_lock(v4_v5_space_setting_att)
        # #     Dim iLock (2)
        # #     v4_v5_space_setting_att.SetDetailsModeWireframeLock iLock
        # #     set_details_mode_wireframe_lock = iLock
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_external_max_deformation_lock(self, i_lock: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetExternalMaxDeformationLock(boolean iLock)
                | 
                |     Locks or unlocks the "External Control Point Maximum Deformation" setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_lock:
        :rtype: None
        """
        return self.v4_v5_space_setting_att.SetExternalMaxDeformationLock(i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_external_max_deformation_lock'
        # # vba_code = """
        # # Public Function set_external_max_deformation_lock(v4_v5_space_setting_att)
        # #     Dim iLock (2)
        # #     v4_v5_space_setting_att.SetExternalMaxDeformationLock iLock
        # #     set_external_max_deformation_lock = iLock
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_external_type_deformation_lock(self, i_lock: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetExternalTypeDeformationLock(boolean iLock)
                | 
                |     Locks or unlocks the activation mode with external deformation (Gap
                |     Healing).
                |     Role:Locks or unlocks the activation mode with external deformation if it
                |     is possible
                |     Refer to SettingController for a detailed description.

        :param bool i_lock:
        :rtype: None
        """
        return self.v4_v5_space_setting_att.SetExternalTypeDeformationLock(i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_external_type_deformation_lock'
        # # vba_code = """
        # # Public Function set_external_type_deformation_lock(v4_v5_space_setting_att)
        # #     Dim iLock (2)
        # #     v4_v5_space_setting_att.SetExternalTypeDeformationLock iLock
        # #     set_external_type_deformation_lock = iLock
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_internal_max_deformation_lock(self, i_lock: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetInternalMaxDeformationLock(boolean iLock)
                | 
                |     Locks or unlocks the "Internal Control Point Maximum Deformation" setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_lock:
        :rtype: None
        """
        return self.v4_v5_space_setting_att.SetInternalMaxDeformationLock(i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_internal_max_deformation_lock'
        # # vba_code = """
        # # Public Function set_internal_max_deformation_lock(v4_v5_space_setting_att)
        # #     Dim iLock (2)
        # #     v4_v5_space_setting_att.SetInternalMaxDeformationLock iLock
        # #     set_internal_max_deformation_lock = iLock
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_internal_type_deformation_lock(self, i_lock: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetInternalTypeDeformationLock(boolean iLock)
                | 
                |     Locks or unlocks the activation mode with internal deformation (Curve
                |     Improvement).
                |     Role:Locks or unlocks the activation mode with external deformation if it
                |     is possible
                |     Refer to SettingController for a detailed description.

        :param bool i_lock:
        :rtype: None
        """
        return self.v4_v5_space_setting_att.SetInternalTypeDeformationLock(i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_internal_type_deformation_lock'
        # # vba_code = """
        # # Public Function set_internal_type_deformation_lock(v4_v5_space_setting_att)
        # #     Dim iLock (2)
        # #     v4_v5_space_setting_att.SetInternalTypeDeformationLock iLock
        # #     set_internal_type_deformation_lock = iLock
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_keep_segmentation_lock(self, i_lock: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetKeepSegmentationLock(boolean iLock)
                | 
                |     Locks or unlocks the KeepSegmentation setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_lock:
        :rtype: None
        """
        return self.v4_v5_space_setting_att.SetKeepSegmentationLock(i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_keep_segmentation_lock'
        # # vba_code = """
        # # Public Function set_keep_segmentation_lock(v4_v5_space_setting_att)
        # #     Dim iLock (2)
        # #     v4_v5_space_setting_att.SetKeepSegmentationLock iLock
        # #     set_keep_segmentation_lock = iLock
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_solid_mu_lock(self, i_lock: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetSolidMULock(boolean iLock)
                | 
                |     Locks or unlocks the Solid Mock-Up Migration Mode setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_lock:
        :rtype: None
        """
        return self.v4_v5_space_setting_att.SetSolidMULock(i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_solid_mu_lock'
        # # vba_code = """
        # # Public Function set_solid_mu_lock(v4_v5_space_setting_att)
        # #     Dim iLock (2)
        # #     v4_v5_space_setting_att.SetSolidMULock iLock
        # #     set_solid_mu_lock = iLock
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_text_migration_lock(self, i_lock: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetTextMigrationLock(boolean iLock)
                | 
                |     Locks or unlocks the 3D Text Migration setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_lock:
        :rtype: None
        """
        return self.v4_v5_space_setting_att.SetTextMigrationLock(i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_text_migration_lock'
        # # vba_code = """
        # # Public Function set_text_migration_lock(v4_v5_space_setting_att)
        # #     Dim iLock (2)
        # #     v4_v5_space_setting_att.SetTextMigrationLock iLock
        # #     set_text_migration_lock = iLock
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'V4V5SpaceSettingAtt(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_list_of_objects import SchListOfObjects
from pycatia.system_interfaces.any_object import AnyObject


class SchAppGroup(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchAppGroup
                | 
                | Manage application group.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_app_group = com_object

    def list_zones(self, i_class_type: str, o_l_zones: SchListOfObjects) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ListZones(CATBSTR iClassType,
                | SchListOfObjects oLZones)
                | 
                |     List application zone objects.
                | 
                |     Parameters:
                | 
                |         iClassType
                |             Class type filter. If null, no filtering will be applied.
                |             
                |         oLZones
                |             (members are CATISchAppZone interfaces pointers) A list of zones
                |             
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppGroup
                |          Dim strVar1 As String
                |          Dim objArg2 As SchListOfObjects
                |           ...
                |          objThisIntf.ListZonesstrVar1,objArg2

        :param str i_class_type:
        :param SchListOfObjects o_l_zones:
        :rtype: None
        """
        return self.sch_app_group.ListZones(i_class_type, o_l_zones.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'list_zones'
        # # vba_code = """
        # # Public Function list_zones(sch_app_group)
        # #     Dim iClassType (2)
        # #     sch_app_group.ListZones iClassType
        # #     list_zones = iClassType
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SchAppGroup(name="{self.name}")'
